pub struct GrainPlugin { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world grain-plugin.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
GrainPlugin::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
GrainPluginPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesGrainPluginPre::instantiateto create aGrainPlugin. -
If you’ve instantiated the instance yourself already then you can use
GrainPlugin::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl GrainPlugin
impl GrainPlugin
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<GrainPlugin>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<GrainPlugin>
Convenience wrapper around GrainPluginPre::new and
GrainPluginPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<GrainPlugin>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<GrainPlugin>
Convenience wrapper around GrainPluginIndices::new and
GrainPluginIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<GrainPlugin>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<GrainPlugin>where
_T: Send,
Convenience wrapper around GrainPluginPre::new and
GrainPluginPre::instantiate_async.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
pub fn grain_plugin_plugin(&self) -> &Guest