pub struct GrainPluginIndices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
grain-plugin.
This is an implementation detail of GrainPluginPre and can
be constructed if needed as well.
For more information see GrainPlugin as well.
Implementations
Sourceimpl GrainPluginIndices
impl GrainPluginIndices
Sourcepub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
Creates a new copy of GrainPluginIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<GrainPlugin>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<GrainPlugin>
Uses the indices stored in self to load an instance
of GrainPlugin from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.